import { ITable } from 'aws-cdk-lib/aws-dynamodb';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { Construct } from 'constructs';
import { LambdaConfiguration } from '../../types';
import { TableItem } from './handler/types/table-item';
/**
 * Properties for the DynamoDbProvisionTable construct.
 */
export interface DynamoDbProvisionTableProps {
    /**
     * Table to provision
     */
    readonly table: DynamoDbProvisionTable.TableProps;
    /**
     * Items to provision within the DynamoDB table
     */
    readonly items: TableItem[];
    /**
     * Encryption key for protecting the framework resources
     */
    readonly encryption?: IKey;
    /**
     * Optional Lambda configuration settings.
     */
    readonly lambdaConfiguration?: LambdaConfiguration;
}
/**
 * Manages provisioning a DynamoDB table
 */
export declare class DynamoDbProvisionTable extends Construct {
    /**
     * Mapping of providers for each CDK stack
     * Used to ensure only one provider is created per stack
     */
    private static serviceTokens;
    /**
     * Builds the provider to support the Custom Resource
     *
     * @param scope Parent to which the Custom Resource belongs
     * @param props Metadata for configuring the Custom Resource
     *
     * @returns Provider for the worker
     */
    private static getOrBuildProvider;
    /**
     * Translates the CDK construct properties to the Custom Resource
     * property format
     * @param props Metadata for configuring the Custom Resource
     * @returns Input for the actual Custom Resource worker
     */
    private static createCustomResourceProperties;
    /**
     * Provisions an existing DynamoDB Table with user-specified data
     * @param scope Parent to which the Custom Resource belongs
     * @param id Unique identifier for this instance
     * @param props Metadata for configuring the Custom Resource
     */
    constructor(scope: Construct, id: string, props: DynamoDbProvisionTableProps);
}
export declare namespace DynamoDbProvisionTable {
    /**
     * Information about the table to provision
     */
    interface TableProps {
        /**
         * CDK representation of the table itself
         */
        readonly resource: ITable;
        /**
         * Name of the partition key for the table
         */
        readonly partitionKeyName: string;
        /**
         * Name of the sort key for the table if applicable
         */
        readonly sortKeyName?: string;
        /**
         * Optional existing encryption key associated with the table
         */
        readonly encryption?: IKey;
    }
}
